@@ -8,3 +8,8 @@ class AuxReward:
     @abstractmethod
     def __call__(self, obs, action, env_reward):
         pass
+
+    def update(self, env_info):
+        """This is called in every time step."""
+
+        pass
